{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% trans "Link Checker" %}{% endblock %}
{% block content %}

<header class="nice-padding">
    <div class="row">
        <div class="left">
            <div class='col'>
                <h1 class="icon icon-link">{% blocktrans %}Link Checker{% endblocktrans %} </h1>
            </div>
        </div>
        <div class='right'>
			<a href="{% url 'wagtaillinkchecker' %}" class="button">{% blocktrans %}Scan Index{% endblocktrans %}</a>
        </div>
    </div>
</header>

<div class="nice-padding">
	<form method="POST" action=''>
		{% csrf_token %}
		{{edit_handler.render_form_content}}
		<input type="submit" value="{% trans 'Save' %}" class="button" />
	</form>
</div>
{% endblock %}
